<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2007 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id$
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() .	'/ec_mainOrderDb.php');
require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');

class admin_ec_mainOrderWidgetContainer extends BaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	private $langId;			// 言語ID
	private $productDb;	// DB接続オブジェクト
	private $serialNo;			// シリアル番号
	private $currency;			// 通貨
	private $orderStatus;		// 受注ステータス
	private $custmState;		// 顧客都道府県
	private $delivState;		// 配送都道府県
	private $billState;		// 請求都道府県
	private $deliveryMethod;		// 配送方法
	private $payMethod;			// 支払い方法
	private $serialArray = array();			// シリアル番号の配列
	const STANDARD_PRICE = 'selling';		// 通常価格
	const ORDER_STATUS_CLOSE = 500;			// 受注処理終了
	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
	const THIS_WIDGET_ID = 'ec_main';
	const TARGET_WIDGET = 'ec_main';		// 呼び出しウィジェットID
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		global $gInstanceManager;
		
		// 親クラスを呼び出す
		parent::__construct();
		
		// DBオブジェクト作成
		$this->db = new ec_mainOrderDb();
		$this->productDb = new productDb();
		
		// 価格計算用オブジェクト取得
		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{
		return 'admin_order.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		global $gEnvManager;

		// ユーザ情報、表示言語
		$this->now = date("Y/m/d H:i:s");	// 現在日時
		$defaultLang	= $gEnvManager->getDefaultLanguage();
		$defaultLangName = $gEnvManager->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
		$this->langId = $defaultLang;		// デフォルト言語
		$this->userId = $gEnvManager->getCurrentUserId();
		
		$act = $request->trimValueOf('act');
		$this->serialNo = $request->trimValueOf('serial');			// 選択項目のシリアル番号
		if (empty($this->serialNo)) $this->serialNo = 0;
				
		// 入力項目
		$name = $request->trimValueOf('item_name');		// 顧客名
		$nameKana = $request->trimValueOf('item_name_kana');		// 顧客名(カナ)
		$custm_zipcode = $request->trimValueOf('item_custm_zipcode');		// 顧客郵便番号
		$custm_address = $request->trimValueOf('item_custm_address');		// 顧客住所
		$custm_phone = $request->trimValueOf('item_custm_phone');		// 顧客電話番号
		$custm_fax = $request->trimValueOf('item_custm_fax');		// 顧客FAX
		
		$deliv_name = $request->trimValueOf('item_deliv_name');		// 配送先名
		$deliv_name_kana = $request->trimValueOf('item_deliv_name_kana');		// 配送先名(カナ)
		$deliv_zipcode = $request->trimValueOf('item_deliv_zipcode');		// 配送先郵便番号
		$deliv_address = $request->trimValueOf('item_deliv_address');		// 配送先住所
		$deliv_phone = $request->trimValueOf('item_deliv_phone');		// 配送先電話番号
		$deliv_fax = $request->trimValueOf('item_deliv_fax');		// 配送先FAX
		$bill_name = $request->trimValueOf('item_bill_name');		// 請求先名
		$bill_name_kana = $request->trimValueOf('item_bill_name_kana');		// 請求先名(カナ)
		$bill_zipcode = $request->trimValueOf('item_bill_zipcode');		// 請求先郵便番号
		$bill_address = $request->trimValueOf('item_bill_address');		// 請求先住所
		$bill_phone = $request->trimValueOf('item_bill_phone');		// 請求先電話番号
		$bill_fax = $request->trimValueOf('item_bill_fax');		// 請求先FAX
		$this->deliveryMethod = $request->trimValueOf('item_delivery_method');		// 選択中の配送方法
		$this->payMethod = $request->trimValueOf('item_payment_method');			// 選択中の支払い方法
		$this->custmState = $request->trimValueOf('item_custm_state');		// 顧客都道府県
		$this->delivState = $request->trimValueOf('item_deliv_state');		// 配送都道府県
		$this->billState = $request->trimValueOf('item_bill_state');		// 請求都道府県

		$this->orderStatus = $request->trimValueOf('item_order_status');		// 受注ステータス
		
		if ($act == 'select'){		// 項目選択の場合
			if ($this->serialNo == 0){		// シリアル番号が0のときは、新規追加モードにする
				$name = '';		// 顧客名
				$nameKana = '';		// 顧客名(カナ)
				$custm_zipcode = '';		// 顧客郵便番号
				$custm_address = '';		// 顧客住所
				$custm_phone = '';		// 顧客電話番号
				$custm_fax = '';		// 顧客FAX
				$deliv_name = '';		// 配送先名
				$deliv_name_kana = '';		// 配送先名(カナ)
				$deliv_zipcode = '';		// 配送先郵便番号
				$deliv_address = '';		// 配送先住所
				$deliv_phone = '';		// 配送先電話番号
				$deliv_fax = '';		// 配送先FAX
				$bill_name = '';		// 請求先名
				$bill_name_kana = '';		// 請求先名(カナ)
				$bill_zipcode = '';		// 請求先郵便番号
				$bill_address = '';		// 請求先住所
				$bill_phone = '';		// 請求先電話番号
				$bill_fax = '';		// 請求先FAX
				$this->deliveryMethod = '';		// 選択中の配送方法
				$this->payMethod = '';			// 選択中の支払い方法
				$this->custmState = 0;		// 顧客都道府県
				$this->delivState = 0;		// 配送都道府県
				$this->billState = 0;		// 請求都道府県
				$this->orderStatus = 0;		// 受注ステータス
			} else {
				// データ再取得
				$ret = $this->db->getOrderBySerial($this->serialNo, $row);
				if ($ret){
					// 取得値を設定
					$this->langId = $row['or_language_id'];		// 受注時の言語
					$orderNo = $row['or_order_no'];		// 受注番号
					
					// ログインユーザ情報を取得
					$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
					if ($ret) $email = $loginUserRow['lu_account'];
					
					$name = $row['or_custm_name'];		// 顧客名
					$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
					$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
					$custm_address = $row['or_custm_address'];		// 顧客住所
					$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
					$custm_fax = $row['or_custm_fax'];		// 顧客FAX
					
					$deliv_name = $row['or_deliv_name'];		// 配送先名
					$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
					$deliv_zipcode = $row['or_deliv_zipcode'];		// 配送先郵便番号
					$deliv_address = $row['or_deliv_address'];		// 配送先住所
					$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
					$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
					$bill_name = $row['or_bill_name'];		// 請求先名
					$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
					$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
					$bill_address = $row['or_bill_address'];		// 請求先住所
					$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
					$bill_fax = $row['or_bill_fax'];		// 請求先FAX
					$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
					$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
					$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
					$this->delivState = $row['or_deliv_state_id'];		// 配送都道府県
					$this->billState = $row['or_bill_state_id'];		// 請求都道府県
	
					$this->orderStatus = $row['or_order_status'];		// 受注ステータス
					$this->currency	= $row['or_currency_id'];	// 通貨
					$subtotal = $row['or_subtotal'];		// 商品総額
					$delivFee = $row['or_deliv_fee'];		// 配送料
					$total = $row['or_total'];		// 総額
					
					$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
					$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
					
					// 受注商品を取得
					$this->db->getOrderDetailList($row['or_id'], array($this, 'orderItemLoop'));
				}
			}
		} else if ($act == 'update'){		// 項目更新の場合
			// 入力チェック
			$this->checkInput($name,				'顧客名');		
			$this->checkInput($nameKana,			'顧客名(カナ)');
			$this->checkSingleByte($custm_zipcode,	'顧客郵便番号');
			$this->checkNumeric($this->custmState,	'顧客都道府県');
			$this->checkInput($custm_address,		'顧客住所');	
			$this->checkSingleByte($custm_phone,	'顧客電話番号');
			$this->checkSingleByte($custm_fax,		'顧客FAX', true);
			
			$this->checkInput($deliv_name,			'配送先名', true);		
			$this->checkInput($deliv_name_kana,		'配送先名(カナ)', true);
			$this->checkSingleByte($deliv_zipcode,	'配送先郵便番号', true);
			$this->checkNumeric($this->delivState,	'配送先都道府県', true);
			$this->checkInput($deliv_address,		'配送先住所', true);	
			$this->checkSingleByte($deliv_phone,	'配送先電話番号', true);
			$this->checkSingleByte($deliv_fax,		'配送先FAX', true);
			
			$this->checkInput($bill_name,			'請求先名', true);		
			$this->checkInput($bill_name_kana,		'請求先名(カナ)', true);
			$this->checkSingleByte($bill_zipcode,	'請求先郵便番号', true);
			$this->checkNumeric($this->billState,	'請求先都道府県', true);
			$this->checkInput($bill_address,		'請求先住所', true);	
			$this->checkSingleByte($bill_phone,		'請求先電話番号', true);
			$this->checkSingleByte($bill_fax,		'請求先FAX', true);
						
			// エラーなしの場合は、データを登録
			if ($this->getMsgCount() == 0){
				// データ取得
				$ret = $this->db->getOrderBySerial($this->serialNo, $row);
				if ($ret){
					// トランザクションスタート
					$this->db->startTransaction();
				
					// 受注ヘッダ作成
					$ret = $this->db->updateOrder($this->serialNo, $this->userId, $this->langId, $row['or_order_no'],
						$row['or_custm_id'], $name, $nameKana, $row['or_custm_person'], $row['or_custm_person_kana'],
						$custm_zipcode, $this->custmState, $custm_address, $custm_phone, $custm_fax, $row['or_custm_country_id'], 
						$row['or_deliv_id'], $deliv_name, $deliv_name_kana, $row['or_deliv_person'], $row['or_deliv_person_kana'],
						$deliv_zipcode, $this->delivState, $deliv_address, $deliv_phone, $deliv_fax, $row['or_deliv_country_id'],
						$row['or_bill_id'], $bill_name, $bill_name_kana, $row['or_bill_person'], $row['or_bill_person_kana'], 
						$bill_zipcode, $this->billState, $bill_address, $bill_phone, $bill_fax, $row['or_bill_country_id'],
						$this->deliveryMethod, $this->payMethod, $row['or_card_type'], $row['or_card_owner'], $row['or_card_number'], $row['or_card_expires'],
						$row['or_demand_dt'], $row['or_appoint_dt'], $row['or_currency_id'], $row['or_subtotal'], $row['or_discount'], $row['or_deliv_fee'], $row['or_charge'], $row['or_total'],
						$this->orderStatus, $row['or_estimate_dt'], $row['or_regist_dt'], $row['or_order_dt'], $row['or_deliv_dt'], $row['or_close_dt'],
						$this->userId, $this->now, $newOrderId, $newSerial);
						
					// トランザクション終了
					$ret = $this->db->endTransaction();
				
					if ($ret){
						$this->setGuidanceMsg('データを更新しました');
					
						// 登録済みのカテゴリーを取得
						$this->serialNo = $newSerial;

						// データ再取得
						$ret = $this->db->getOrderBySerial($this->serialNo, $row);
						if ($ret){
							// 取得値を設定
							$this->langId = $row['or_language_id'];		// 受注時の言語
							$orderNo = $row['or_order_no'];		// 受注番号
					
							// ログインユーザ情報を取得
							$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
							if ($ret) $email = $loginUserRow['lu_account'];
					
							$name = $row['or_custm_name'];		// 顧客名
							$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
							$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
							$custm_address = $row['or_custm_address'];		// 顧客住所
							$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
							$custm_fax = $row['or_custm_fax'];		// 顧客FAX
					
							$deliv_name = $row['or_deliv_name'];		// 配送先名
							$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
							$deliv_zipcode = $row['or_deliv_zipcode'];		// 配送先郵便番号
							$deliv_address = $row['or_deliv_address'];		// 配送先住所
							$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
							$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
							$bill_name = $row['or_bill_name'];		// 請求先名
							$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
							$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
							$bill_address = $row['or_bill_address'];		// 請求先住所
							$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
							$bill_fax = $row['or_bill_fax'];		// 請求先FAX
							$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
							$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
							$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
							$this->delivState = $row['or_deliv_state_id'];		// 配送都道府県
							$this->billState = $row['or_bill_state_id'];		// 請求都道府県
	
							$this->orderStatus = $row['or_order_status'];		// 受注ステータス
							$this->currency	= $row['or_currency_id'];	// 通貨
							$subtotal = $row['or_subtotal'];		// 商品総額
							$delivFee = $row['or_deliv_fee'];		// 配送料
							$total = $row['or_total'];		// 総額
					
							$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
							$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
					
							// 受注商品を取得
							$this->db->getOrderDetailList($row['or_id'], array($this, 'orderItemLoop'));
						}
					} else {
						$this->setAppErrorMsg('データ更新に失敗しました');
					}
				}
			}
		} else if ($act == 'delete'){		// 項目削除の場合
			if (empty($this->serialNo)){
				$this->setUserErrorMsg('削除項目が選択されていません');
			}
			// エラーなしの場合は、データを削除
			if ($this->getMsgCount() == 0){
				$ret = $this->db->delOrder($this->serialNo, $this->userId);
				if ($ret){		// データ削除成功のとき
					$this->setGuidanceMsg('データを削除しました');
				} else {
					$this->setAppErrorMsg('データ削除に失敗しました');
				}
			}
		} else {	// 初期表示
			// 入力値初期化
			$name = '';		// 顧客名
			$nameKana = '';		// 顧客名(カナ)
			$custm_zipcode = '';		// 顧客郵便番号
			$custm_address = '';		// 顧客住所
			$custm_phone = '';		// 顧客電話番号
			$custm_fax = '';		// 顧客FAX
			$deliv_name = '';		// 配送先名
			$deliv_name_kana = '';		// 配送先名(カナ)
			$deliv_zipcode = '';		// 配送先郵便番号
			$deliv_address = '';		// 配送先住所
			$deliv_phone = '';		// 配送先電話番号
			$deliv_fax = '';		// 配送先FAX
			$bill_name = '';		// 請求先名
			$bill_name_kana = '';		// 請求先名(カナ)
			$bill_zipcode = '';		// 請求先郵便番号
			$bill_address = '';		// 請求先住所
			$bill_phone = '';		// 請求先電話番号
			$bill_fax = '';		// 請求先FAX
			$this->deliveryMethod = '';		// 選択中の配送方法
			$this->payMethod = '';			// 選択中の支払い方法
			$this->custmState = 0;		// 顧客都道府県
			$this->delivState = 0;		// 配送都道府県
			$this->billState = 0;		// 請求都道府県
			$this->orderStatus = 0;		// 受注ステータス
		}
		
		// #### 受注状況リストを作成 ####
		// レコード削除されていないもの、終了していないものを取得
		$this->db->getOrderHeaderByStatus(array($this, 'orderListLoop'), 0, self::ORDER_STATUS_CLOSE -1);
		
		// 選択中の受注IDを設定
		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
		if ($this->serialNo == 0){		// シリアル番号が0のときは新規とする
			$this->tmpl->addVar("_widget", "order_no", '新規');
			
			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
		} else {
			$this->tmpl->addVar("_widget", "order_no", $orderNo);
		}

		$this->tmpl->addVar("_widget", "name", $name);		// 顧客名
		$this->tmpl->addVar("_widget", "name_kana", $nameKana);		// 顧客名(カナ)
		$this->tmpl->addVar("_widget", "email", $email);		// Eメールアドレス
		$this->tmpl->addVar("_widget", "custm_zipcode", $custm_zipcode);		// 顧客郵便番号
		$this->tmpl->addVar("_widget", "custm_address", $custm_address);		// 顧客住所
		$this->tmpl->addVar("_widget", "custm_phone", $custm_phone);		// 顧客電話番号
		$this->tmpl->addVar("_widget", "custm_fax", $custm_fax);		// 顧客FAX
		
		$this->tmpl->addVar("_widget", "deliv_name", $deliv_name);		// 配送先名		
		$this->tmpl->addVar("_widget", "deliv_name_kana", $deliv_name_kana);		// 配送先名(カナ)	
		$this->tmpl->addVar("_widget", "deliv_zipcode", $deliv_zipcode);		// 配送先郵便番号
		$this->tmpl->addVar("_widget", "deliv_address", $deliv_address);		// 配送先住所
		$this->tmpl->addVar("_widget", "deliv_phone", $deliv_phone);		// 配送先電話番号
		$this->tmpl->addVar("_widget", "deliv_fax", $deliv_fax);		// 配送先FAX
		$this->tmpl->addVar("_widget", "bill_name", $bill_name);		// 請求先名		
		$this->tmpl->addVar("_widget", "bill_name_kana", $bill_name_kana);		// 請求先名(カナ)
		$this->tmpl->addVar("_widget", "bill_zipcode", $bill_zipcode);		// 請求先郵便番号
		$this->tmpl->addVar("_widget", "bill_address", $bill_address);		// 請求先住所
		$this->tmpl->addVar("_widget", "bill_phone", $bill_phone);		// 請求先電話番号
		$this->tmpl->addVar("_widget", "bill_fax", $bill_fax);		// 請求先FAX
		
		$subtotalStr = $this->ecObj->convertByCurrencyFormat($this->currency, $this->langId, $subtotal);
		$this->tmpl->addVar("_widget", "subtotal", $subtotalStr);		// 商品総額
		$delivFeeStr = $this->ecObj->convertByCurrencyFormat($this->currency, $this->langId, $delivFee);
		$this->tmpl->addVar("_widget", "delivery_fee", $delivFeeStr);		// 送料、手数料
		$totalStr = $this->ecObj->convertByCurrencyFormat($this->currency, $this->langId, $total);
		$this->tmpl->addVar("_widget", "total", $totalStr);		// 総額
		
		if (!empty($updateUser)) $this->tmpl->addVar("_widget", "update_user", $updateUser);	// 更新者
		if (!empty($updateDt)) $this->tmpl->addVar("_widget", "update_dt", $updateDt);	// 更新日時

		// 受注ステータスメニューを作成
		$this->db->getAllOrderStatus($this->langId, array($this, 'orderStatusLoop'));
		
		// 顧客都道府県を設定
		$this->db->getAllState('JPN', $this->langId, array($this, 'customStateLoop'));
		
		// 配送先都道府県を設定
		$this->db->getAllState('JPN', $this->langId, array($this, 'delivStateLoop'));
		
		// 請求先都道府県を設定
		$this->db->getAllState('JPN', $this->langId, array($this, 'billStateLoop'));
		
		// 配送方法メニューを作成
		$this->db->getAllDeliveryMethod($this->langId, array($this, 'deliveryMethodLoop'));
		
		// 支払い方法メニューを作成
		$this->db->getAllPaymentMethod($this->langId, array($this, 'paymentMethodLoop'));
			
		// ボタンの設定
		if ($this->serialNo == 0){		// 新規追加項目を選択しているとき
			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
		} else {
			// データ更新、削除ボタン表示
			$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');// 削除ボタン
			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
		}
					
		// 非表示項目の設定
		$this->tmpl->addVar("_widget", "serial", $this->serialNo);

		// 表示中の項目のを設定
		$serialList = '';
		if (!empty($this->serialArray)) $serialList = implode($this->serialArray, ',');
		$this->tmpl->addVar("_widget", "serial_list", $serialList);
		
		// パスの設定
		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
		$this->tmpl->addVar("_widget", "image_path", $gEnvManager->getRootUrl() . '/resource/');		// 画像の格納場所
	}
	/**
	 * 取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function orderListLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		// 行カラーの設定
		$lineColor = '';
		if ($index % 2 != 0){
			$lineColor = 'class="even"';		// 偶数行
		}
		// 項目選択のラジオボタンの状態
		$selected = '';
		if ($fetchedRow['or_serial'] == $this->serialNo){
			$selected = 'checked';
		}

		// 購入金額
		$this->ecObj->setCurrencyType($this->currency, $this->langId);		// 通貨設定
		$this->ecObj->getPriceWithoutTax($fetchedRow['or_total'], $dispPrice);		// 表示文字列作成
		
		// 受注ステータス
		$ret = $this->db->getOrderStatusName($fetchedRow['or_order_status'], $this->langId, $row);
		if ($ret) $status = $row['os_name'];
			
		// 配送日時
		$delibDt = '';
		if ($fetchedRow['or_deliv_dt'] != $gEnvManager->getInitValueOfTimestamp()) $delibDt = $this->convertToDispDateTime($fetchedRow['or_deliv_dt']);
		
		$row = array(
			'line_color' => $lineColor,											// 行のカラー
			'no' => $index + 1,													// 行番号
			'serial' => $this->convertToDispString($fetchedRow['or_serial']),	// シリアル番号
			'id' => $id,			// ID
			'order_no' => $this->convertToDispString($fetchedRow['or_order_no']),		// 受注番号
			'name' => $this->convertToDispString($fetchedRow['or_custm_name']),		// 顧客名
			'total' => $dispPrice,		// 購入額
			'status' => $status,		// 受注ステータス
			'lang' => $lang,													// 対応言語
			'regist_dt' => $this->convertToDispDateTime($fetchedRow['or_regist_dt']),	// 受付日時
			'deliv_dt' => $delibDt,	// 配送日時
			//'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
			//'update_dt' => $this->convertToDispDateTime($fetchedRow['pt_create_dt']),	// 更新日時
			'default' => $default,											// デフォルト項目
			'selected' => $selected												// 項目選択用ラジオボタン
		);
		$this->tmpl->addVars('itemlist', $row);
		$this->tmpl->parseTemplate('itemlist', 'a');
		
		// 表示中の項目のシリアル番号を保存
		$this->serialArray[] = $fetchedRow['or_serial'];
		return true;
	}
	/**
	 * 取得したデータをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function orderItemLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		// 行カラーの設定
		$lineColor = '';
		if ($index % 2 != 0){
			$lineColor = 'class="even"';		// 偶数行
		}
		
		$priceStatus = 1;	// 価格が有効であるかどうか
		$id = $fetchedRow['od_product_id'];	// 商品ID
		
		// 商品を取得
		$ret = $this->productDb->getProductByProductId($id, $this->langId, $row, $row2, $row3, $row4);
		if ($ret){
			$name = $this->convertToDispString($row['pt_name']);		// 名前
			$code = $this->convertToDispString($row['pt_code']);		// 商品コード
			
			// 商品の現在価格を取得
			// 価格を取得
			$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
			$price = $priceArray['pp_price'];	// 価格
			$currency = $priceArray['pp_currency_id'];	// 通貨
			$taxType = $row['pt_tax_type_id'];					// 税種別
					
			// 価格作成
			$this->ecObj->setCurrencyType($currency, $this->langId);		// 通貨設定
			$this->ecObj->setTaxType($taxType, $this->langId);		// 税種別設定
			$unitPrice = $this->ecObj->getPriceWithTax($price, $dispUnitPrice);	// 税込み価格取得
			
			// 商品が表示不可のときは価格を無効とする
			if (!$row['pt_visible']) $priceStatus = 0;
		} else {
			// 商品情報が取得できないときは価格無効
			$priceStatus = 0;
		}
		
		// 価格が変更のときは、価格を無効にする
		$quantity = $fetchedRow['od_quantity'];
		$subtotal = $fetchedRow['od_total'];
		
		// 通貨情報を取得
		$ret = $this->productDb->getCurrency($this->currency, $this->langId, $row);
		if ($ret){
			$prePrice = $this->convertToDispString($row['cu_symbol']);
			$postPrice = $this->convertToDispString($row['cu_post_symbol']);
		}
		
		// 価格作成
		$this->ecObj->setCurrencyType($this->currency, $this->langId);		// 通貨設定
		$this->ecObj->getPriceWithoutTax($subtotal, $dispPrice);		// 小計の表示文字列作成
		
		// 小計価格
		$available = '';
		if ($priceStatus == 0) $available = '(無効)';
		$price = $prePrice . $dispPrice . $available;
		
		// 商品詳細へのリンク
		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . self::TARGET_WIDGET;
		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . self::THIS_WIDGET_ID;		// 送信元
		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('product=' . $fetchedRow['si_product_id']);
			
		$nameLink = '<a href="' . $url . '">' . $name . '</a>';
		$row = array(
			'line_color' => $lineColor,											// 行のカラー
			'no' => $index + 1,													// 行番号
			'name' => $name,
			'code' => $code,
			'unit_price' => $dispUnitPrice,			// 税込み単価
			'id' => $id,					// 商品ID
			'price' => $price,
			'quantity' => $quantity,
			'price_status' => $priceStatus		// 商品価格が有効かどうか
		);
		$this->tmpl->addVars('product_list', $row);
		$this->tmpl->parseTemplate('product_list', 'a');
		
		$this->productExists = true;			// カートに商品があるかどうか
		return true;
	}
	/**
	 * 価格取得
	 *
	 * @param array  	$srcRows			価格リスト
	 * @param string	$priceType			価格のタイプ
	 * @return array						取得した価格行
	 */
	function getPrice($srcRows, $priceType)
	{
		for ($i = 0; $i < count($srcRows); $i++){
			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
				return $srcRows[$i];
			}
		}
		return array();
	}
	/**
	 * 取得した配送先都道府県をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function customStateLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['gz_id'] == $this->custmState){		// 選択中の都道府県
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['gz_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['gz_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('custm_state_list', $row);
		$this->tmpl->parseTemplate('custm_state_list', 'a');
		return true;
	}
	/**
	 * 取得した配送先都道府県をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function delivStateLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['gz_id'] == $this->delivState){		// 選択中の都道府県
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['gz_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['gz_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('deliv_state_list', $row);
		$this->tmpl->parseTemplate('deliv_state_list', 'a');
		return true;
	}
	/**
	 * 取得した請求先都道府県をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function billStateLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['gz_id'] == $this->billState){		// 選択中の都道府県
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['gz_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['gz_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('bill_state_list', $row);
		$this->tmpl->parseTemplate('bill_state_list', 'a');
		return true;
	}
	/**
	 * 取得した配送方法をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function deliveryMethodLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['dm_id'] == $this->deliveryMethod){		// 選択中の配送方法
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['dm_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['dm_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('delivery_method_list', $row);
		$this->tmpl->parseTemplate('delivery_method_list', 'a');
		return true;
	}
	/**
	 * 取得した支払い方法をテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function paymentMethodLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['pm_id'] == $this->payMethod){		// 選択中の支払い方法
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['pm_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['pm_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('payment_method_list', $row);
		$this->tmpl->parseTemplate('payment_method_list', 'a');
		return true;
	}
	/**
	 * 受注ステータスをテンプレートに設定する
	 *
	 * @param int $index			行番号(0～)
	 * @param array $fetchedRow		フェッチ取得した行
	 * @param object $param			未使用
	 * @return bool					true=処理続行の場合、false=処理終了の場合
	 */
	function orderStatusLoop($index, $fetchedRow, $param)
	{
		global $gEnvManager;

		$selected = '';
		if ($fetchedRow['os_id'] == $this->orderStatus){		// 受注ステータス
			$selected = 'selected';
		}

		$row = array(
			'value'    => $this->convertToDispString($fetchedRow['os_id']),			// ID
			'name'     => $this->convertToDispString($fetchedRow['os_name']),			// 表示名
			'selected' => $selected														// 選択中かどうか
		);
		$this->tmpl->addVars('order_status_list', $row);
		$this->tmpl->parseTemplate('order_status_list', 'a');
		return true;
	}
}
?>
